PyKwiki
=======

PyKwiki is a simple markdown-based static site generator suited for blogs and wikis. 

Features:

* Static keyword search
* YAML configuration
* Markdown
* Templates
* Extensions
* SASS (version 2+)
    

## Install

To install Pykwiki 1x:

    pip install -I pykwiki==1.1.6

To install the latest version: 

    pip install pykwiki

## Documentation

### Older Versions (1x)

Documentation for original PyKwiki can be found at [pykwiki-classic.nullism.com](http://pykwiki-classic.nullism.com). 

### Latest Version (2x)

Documentation for PyKwiki 2x can be found at [pykwiki.nullism.com](http://pykwiki.nullism.com). This is currently a work in progress.
